function [B Price] = BDTDiscountBond2(M,N,d);

% Calculates the price of a zero coupon bond in the Black Derman Toy Model.
% Inputs are:
% M = Number of time periods for the bond (scalar).
% N = Number of time periods for the BDT interest rate tree (scalar.
% d = Tree of discount factors from the BDT tree.  Matrix size (2*N+1) x N.

% Truncate the matrix of discount factors
d = d(N-M+1:N+M+1,1:M+1);

% Initialize the Bond price tree.
B = zeros(2*M+1,M+1);

% Terminal prices of the bonds is 1.
B(:,end) = 1;

% Work backwards through the discount bond tree.
for j=M:-1:1
	for i=M-j+2:2:M+j
		B(i,j) = d(i,j)*0.5*(B(i-1,j+1) + B(i+1,j+1));
	end
end

% Return the first node of the discount bond tree.
Price = B(M+1,1);
