% Black-Derman-Toy interest rate tree fitted to yield curve data.
% Reproduces Figure 8.4 in Clewlow and Strickland's book 
% "Implementing Derivatives Models"

clc; clear;

% Volatility
sigma = .10;

% Number of tree steps (N) and maturity.
N = 10;
T = 10;
dt = T/N;

% Tenors, rates.
Tenors = [1:N+1]';
Rates  = 0.05.*ones(N+1,1);

% Discount factors
P = 1./(1+Rates.*dt).^Tenors;

% Return the interest rate tree (r), the discount factors (d),
% and the Arrow-Debreu securities prices
% Trees will be of size (2N+1, N+1)
[r d Q] = BuildBDTtree_yields(N,Rates(1),P,sigma,dt);


% 10-year zero coupon bond
M = 10;
[B ZCBPrice] = BDTDiscountBond2(M,N,d)


% 6-year put options on the 10-year zero coupon bond.
% Strike price and maturity of the zero coupon bond.
K = .80;
Mat = 6 ;

% Trees and prices
[AmerTree AmerOption] = BDToptions(K,M,N,Mat,B,Q,d,'P','A');
[EuroTree EuroOption] = BDToptions(K,M,N,Mat,B,Q,d,'P','E');
AmerTree
AmerOption
EuroOption 

